@@ -3,9 +3,7 @@ use clap::App;
 use clap::ArgMatches;
 use clap::SubCommand;
 use grid_printer::GridPrinter;
-use grid_printer::style::StyleOpt;
-use grid_printer::style::Fg;
-use crate::client::Client;
+use crate::client::html_client::Client;
 use crate::cli::HnCommand;
 
 /// Get front page listings of Hacker News.
@@ -35,7 +33,6 @@ impl HnCommand for News {
         };
         let printer = GridPrinter::builder(rows, cols)
             .col_spacing(4)
-            .col_style(1, StyleOpt::new().fg(Fg::Red))?
             .build();
         printer.print(&grid);
 
