@@ -1,13 +1,14 @@
 use std::env;
 use std::error::Error;
-use hnews::cli::HnCommand;
-use hnews::cli::hnews::Hnews;
+use hacker_news::cli::HnCommand;
+use hacker_news::cli::hacker_news::HackerNews;
 
 fn main() -> Result<(), Box<dyn Error>> {
-    let app = Hnews::parser();
+    env_logger::init();
+    let app = HackerNews::parser();
     let matches = app.get_matches_from(env::args_os());
 
-    match Hnews::cmd(&matches) {
+    match HackerNews::cmd(&matches) {
         Ok(_) => std::process::exit(0),
         Err(e) => {
             println!("{}", e);
